@@ -8,12 +8,12 @@ use Scalar::Util qw/blessed reftype refaddr/;
 use Data::Dumper;
 use Template;
 use Template::Constants qw/:chomp :debug/;
-use File::ShareDir ':ALL';
+use File::ShareDir::ProjectDistDir 1.0 ':all', strict => 1;
 use Config;
 
 # ABSTRACT: Translate an IDL source to an AST
 
-our $VERSION = '0.002'; # VERSION
+our $VERSION = '0.003'; # VERSION
 
 
 use Carp qw/carp croak/;
@@ -159,7 +159,7 @@ sub generate {
 
 =pod
 
-=encoding utf-8
+=encoding UTF-8
 
 =head1 NAME
 
@@ -167,7 +167,7 @@ MarpaX::Languages::IDL::AST - Translate an IDL source to an AST
 
 =head1 VERSION
 
-version 0.002
+version 0.003
 
 =head1 SYNOPSIS
 
